@@ -16,7 +16,7 @@ def main():
     if args.component_name:
         component_root = Path(__file__).resolve().parents[0]
         os.mkdir(args.component_name)
-        example_dir = component_root / 'rainbond-python-demo.zip'
+        example_dir = component_root / 'demos' / 'rainbond-python-demo.zip'
         extract(str(example_dir), args.component_name)
         print(
             'Successfully created `{0}` component. Run command:\n$ cd {0}\n$ pip3 install -r requirements.txt\n$ python3 app.py'.format(args.component_name))
