@@ -44,10 +44,8 @@ class DBConnect:
             new_data = self.mongo_collection.insert_one(deep_docu)
             return str(new_data.inserted_id)
         except Exception as err:
-            del deep_docu['creation_time']
-            del deep_docu['update_time']
             handle_abnormal(
-                message='MongoDB(组件)出现写入错误: {0}'.format(json.dumps(deep_docu)),
+                message='MongoDB(组件)出现写入错误: {0}'.format(json.dumps(docu)),
                 status=500,
                 other={'prompt': str(err)}
             )
